==> tdebase-trinity-14.1.1.tar.xz: tdebase-trinity-14.1.1/khotkeys/shared/soundrecorder.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Olivier Goffart   *
 *   ogoffart@kde.org   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef RECORDER_H
#define RECORDER_H

#include <tqobject.h>
#include "sound.h"
#include <kdemacros.h>

class KLibrary;

namespace KHotKeys
{



/**
@author Olivier Goffart
*/
class KDE_EXPORT SoundRecorder : public TQObject
{
TQ_OBJECT
public:
    static SoundRecorder* create( TQObject* parent = 0, const char* name = 0 );
    virtual ~SoundRecorder();

    virtual void start();
    virtual void stop();
    virtual void abort();
    virtual Sound sound();

    static bool init( KLibrary* );
signals:
    void recorded(const Sound&);

protected:
    SoundRecorder(TQObject *parent = 0, const char *name = 0);
    typedef SoundRecorder* (*create_ptr)( TQObject*, const char* );
private:
    static create_ptr create_fun;
};

}

#endif

==> tdebase-trinity_14.2.0~pre706.orig.tar.xz: tdebase-trinity-14.2.0~pre706+69126986/khotkeys/shared/soundrecorder.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Olivier Goffart   *
 *   ogoffart@kde.org   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef RECORDER_H
#define RECORDER_H

#include <tqobject.h>
#include "sound.h"
#include <tdemacros.h>

class KLibrary;

namespace KHotKeys
{



/**
@author Olivier Goffart
*/
class TDE_EXPORT SoundRecorder : public TQObject
{
TQ_OBJECT
public:
    static SoundRecorder* create( TQObject* parent = 0, const char* name = 0 );
    virtual ~SoundRecorder();

    virtual void start();
    virtual void stop();
    virtual void abort();
    virtual Sound sound();

    static bool init( KLibrary* );
signals:
    void recorded(const Sound&);

protected:
    SoundRecorder(TQObject *parent = 0, const char *name = 0);
    typedef SoundRecorder* (*create_ptr)( TQObject*, const char* );
private:
    static create_ptr create_fun;
};

}

#endif
